@@ -568,7 +568,7 @@ main(int argc, char **argv)
 
     gtk_window_set_default_icon_name("accessories-calculator");
 
-    app = gtk_application_new("org.gnome.gcalctool", G_APPLICATION_FLAGS_NONE);
+    app = gtk_application_new(NULL, G_APPLICATION_NON_UNIQUE);
     g_signal_connect(app, "startup", G_CALLBACK(startup_cb), NULL);
     g_signal_connect(app, "activate", G_CALLBACK(activate_cb), NULL);
 
